pub struct CreateConfig {
pub config_parameters: ConfigParameters,
}Fields
config_parameters: ConfigParametersTrait Implementations
Sourceimpl ArrangeAccounts for CreateConfig
impl ArrangeAccounts for CreateConfig
type ArrangedAccounts = CreateConfigInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for CreateConfigwhere
ConfigParameters: BorshDeserialize,
impl BorshDeserialize for CreateConfigwhere
ConfigParameters: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for CreateConfig
impl CarbonDeserialize for CreateConfig
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for CreateConfig
impl Clone for CreateConfig
Sourcefn clone(&self) -> CreateConfig
fn clone(&self) -> CreateConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateConfig
impl Debug for CreateConfig
Sourceimpl<'de> Deserialize<'de> for CreateConfig
impl<'de> Deserialize<'de> for CreateConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for CreateConfig
impl Hash for CreateConfig
Sourceimpl PartialEq for CreateConfig
impl PartialEq for CreateConfig
Sourceimpl Serialize for CreateConfig
impl Serialize for CreateConfig
impl Eq for CreateConfig
impl StructuralPartialEq for CreateConfig